@@ -14,6 +14,8 @@ class Confluence(AtlassianRestAPI):
         ".jpg": "image/jpeg",
         ".jpeg": "image/jpeg",
         ".pdf": "application/pdf",
+        ".doc": "application/msword",
+        ".xls": "application/vnd.ms-excel",
     }
 
     def page_exists(self, space, title):
@@ -319,8 +321,10 @@ class Confluence(AtlassianRestAPI):
                 'X-Atlassian-Token': 'nocheck',
                 'Accept': 'application/json'}
             path = 'rest/api/content/{page_id}/child/attachment'.format(page_id=page_id)
+            # get base name of the file to get the attachment from confluence.
+            file_base_name = os.path.basename(filename)
             # Check if there is already a file with the same name
-            attachments = self.get(path=path, headers=headers, params={'filename': filename})
+            attachments = self.get(path=path, headers=headers, params={'filename': file_base_name})
             if attachments['size']:
                 path = path + '/' + attachments['results'][0]['id'] + '/data'
             with open(filename, 'rb') as infile:
@@ -366,7 +370,7 @@ class Confluence(AtlassianRestAPI):
         :param body: Body for compare it
         :return: True if the same
         """
-        confluence_content = self.get_page_by_id(page_id, expand='body.storage')['body']['storage']['value']
+        confluence_content = (self.get_page_by_id(page_id, expand='body.storage').get('body') or {}).get('storage').get('value')
         confluence_content = confluence_content.replace('&oacute;', u'ó')
 
         log.debug('Old Content: """{body}"""'.format(body=confluence_content))
@@ -506,7 +510,7 @@ class Confluence(AtlassianRestAPI):
 
     def clean_all_caches(self):
         """ Clean all caches from cache management"""
-        headers = {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8', 'X-Atlassian-Token': 'no-check'}
+        headers = self.form_token_headers
         return self.delete('rest/cacheManagement/1.0/cacheEntries', headers=headers)
 
     def clean_package_cache(self, cache_name='com.gliffy.cache.gon'):
@@ -515,7 +519,7 @@ class Confluence(AtlassianRestAPI):
             com.gliffy.cache.gon
             org.hibernate.cache.internal.StandardQueryCache_v5
         """
-        headers = {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8', 'X-Atlassian-Token': 'no-check'}
+        headers = self.form_token_headers
         data = {'cacheName': cache_name}
         return self.delete('rest/cacheManagement/1.0/cacheEntries', data=data, headers=headers)
 
@@ -626,7 +630,7 @@ class Confluence(AtlassianRestAPI):
         :param page_id: Page ID
         :return: PDF File
         """
-        headers = {'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8', 'X-Atlassian-Token': 'no-check'}
+        headers = self.form_token_headers
         url = 'spaces/flyingpdf/pdfpageexport.action?pageId={pageId}'.format(pageId=page_id)
         return self.get(url, headers=headers, not_json_response=True)
 
